#!/bin/busybox sh

usage() {
    echo "Usage:"
    echo "  $0 [options] <target device file name> [ <image> ]"
    echo "Options:"
    echo "  -h"
    echo "     Show this help message."
    echo "  -s"
    echo "     Bytes in input, if not reading from file"
    echo "  -x"
    echo "     Mark image on target device unusable, wipe it out"
    echo
    echo "  image"
    echo "     image to be stored on device, if emtpy stdin is assumed"
    echo
    echo " Exit codes:"
    echo "   0:  Success."
    echo "   1:  Invalid arguments."
}

ERASE=

while getopts "hs:x" option; do
    case $option in
        h)
            usage
            exit 0
            ;;
        s)
            # unused, for compatibility with ubifs
            ;;
        x)
            ERASE=1
            ;;
        \?)
            usage
            exit 1
            ;;
    esac
done

shift $((OPTIND - 1))

DEVICE="$1"
IMAGE="$2"

if [ -z "$DEVICE" ] || [ ! -w "$DEVICE" ] ; then
    echo "ERROR missing device node $DEVICE"
    usage
    exit 1
fi

if [ $ERASE ]; then
    exec "$RESCUE_ROOT_DIR"/bin/dd if=/dev/zero of="$DEVICE"
fi

IMAGE_STRING=""
if [ -n "$IMAGE" ]; then
    if [ ! -r "$IMAGE" ] ; then
        echo "ERROR file not readable $IMAGE"
        exit 2
    fi
    IMAGE_STRING="if=$IMAGE"
fi

# TODO check size of target partition

if [ -n "$IMAGE_STRING" ]; then
    "$RESCUE_ROOT_DIR"/bin/dd "$IMAGE_STRING" of="$DEVICE"
else
    # "dd: unrecognized operand ‘’"
    "$RESCUE_ROOT_DIR"/bin/dd of="$DEVICE"
fi
